summaryrefslogtreecommitdiff
path: root/app/constants.php
diff options
context:
space:
mode:
authorFrédéric Guillot <fred@kanboard.net>2018-03-05 13:34:04 -0800
committerFrédéric Guillot <fred@kanboard.net>2018-03-05 13:34:04 -0800
commit95ac11a6aad8238a8349d8bda421739307987cae (patch)
treeebd4c8ff1bfa8ea9db74a1e7c1b8ea62336d2d6b /app/constants.php
parent299198f7181fccf1e9a684649d173a1ebbdfbd1e (diff)
Add system log driver and use it by default
Diffstat (limited to 'app/constants.php')
-rw-r--r--app/constants.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/app/constants.php b/app/constants.php
index 35d651e8..c47f8e87 100644
--- a/app/constants.php
+++ b/app/constants.php
@@ -26,8 +26,8 @@ defined('PLUGIN_INSTALLER') or define('PLUGIN_INSTALLER', true);
// Enable/disable debug
defined('DEBUG') or define('DEBUG', strtolower(getenv('DEBUG')) === 'true');
-// Logging drivers: syslog, stdout, stderr or file
-defined('LOG_DRIVER') or define('LOG_DRIVER', '');
+// Logging drivers: syslog, stdout, stderr, system or file
+defined('LOG_DRIVER') or define('LOG_DRIVER', 'system');
// Logging file
defined('LOG_FILE') or define('LOG_FILE', DATA_DIR.DIRECTORY_SEPARATOR.'debug.log');